Skip to main content Crate gatel_core Copy item path Source admin Admin REST API server. config events Lightweight pub/sub event bus for inter-module communication. goals hoops observability Observability backends for structured logging. plugin Dynamic module/plugin system for gatel. proxy router runtime Runtime abstraction layer for gatel. salvo_service sd_notify Minimal systemd sd_notify implementation. server storage Pluggable storage abstraction for certificate and persistent data. stream L4 TCP stream proxy. tls TLS certificate management for gatel. ttl_cache ProxyError Top-level error type for the proxy. empty_body Create an empty body. full_body Create a body from bytes. Body The body type used throughout gatel — error is a boxed trait object
so we can unify bodies from different sources (hyper Incoming, Full, Empty, upstream). BoxError Boxed error type alias.