pub struct ClientAuthConfig {
pub ca_certs: Vec<String>,
pub required: bool,
}Expand description
mTLS (mutual TLS) client certificate verification configuration.
Fields
ca_certs: Vec<String>Paths to CA PEM files used to verify client certificates.
required: boolIf true, connections without a valid client certificate are rejected. If false, client certificates are requested but not required.