pub struct FileServerConfig {
pub root: String,
pub browse: bool,
pub trailing_slash: bool,
pub index: Vec<String>,
}Expand description
Static file serving config.
Fields
root: Stringbrowse: booltrailing_slash: boolWhen true (default), redirect directory requests without trailing slash to add one.
index: Vec<String>List of index filenames to try when serving a directory (default: [“index.html”]).