pub struct BufferLimitHoop { /* private fields */ }Expand description
Middleware that enforces request and response body size limits.
- When
max_request_bodyis set: if theContent-Lengthheader of the incoming request exceeds the limit, a 413 Payload Too Large response is returned immediately without forwarding to the upstream. - When
max_response_bodyis set: if theContent-Lengthheader of the upstream response exceeds the limit, a 502 Bad Gateway response is returned instead.
Implementations