pub struct LbContext {
pub client_addr: SocketAddr,
pub uri: String,
pub headers: HeaderMap,
}Expand description
Contextual information about the current request, made available to load-balancing strategies that need more than the pool itself.
Fields
client_addr: SocketAddruri: Stringheaders: HeaderMapAuto Trait Implementations
impl Freeze for LbContext
impl RefUnwindSafe for LbContext
impl Send for LbContext
impl Sync for LbContext
impl Unpin for LbContext
impl UnsafeUnpin for LbContext
impl UnwindSafe for LbContext