pub fn spawn<F>(future: F) -> JoinHandle<F::Output>Expand description
Spawn a new async task on the current runtime.
On tokio: delegates to tokio::spawn.
On monoio: delegates to monoio::spawn (task is !Send, pinned to current thread).
pub fn spawn<F>(future: F) -> JoinHandle<F::Output>Spawn a new async task on the current runtime.
On tokio: delegates to tokio::spawn.
On monoio: delegates to monoio::spawn (task is !Send, pinned to current thread).