pub struct ErrorPagesHoop { /* private fields */ }Expand description
Custom error page middleware.
When the downstream handler produces a response with a status code that matches one of the configured error pages, the response body is replaced with the custom content. This is applied after the inner chain completes.
Implementations