pub struct ForwardAuthHoop { /* private fields */ }Expand description
Forwarded authentication middleware.
Delegates authentication to an external service. For every incoming request the middleware:
- Clones the request headers (no body) and adds
X-Forwarded-Uri(original path+query) andX-Forwarded-Method(original method). - Sends a GET request to
auth_urlwith those headers via reqwest. - If the auth service returns 2xx, copies the configured headers from the auth response into the original request and continues the chain.
- If the auth service returns non-2xx, that response is returned directly to the client.
Implementations